@@ -1,6 +1,6 @@
 package Net::Works::Role::IP;
 {
-  $Net::Works::Role::IP::VERSION = '0.11';
+  $Net::Works::Role::IP::VERSION = '0.12';
 }
 BEGIN {
   $Net::Works::Role::IP::AUTHORITY = 'cpan:DROLSKY';
@@ -14,7 +14,7 @@ use Math::Int128 qw( uint128 );
 use Net::Works::Types qw( Int IPInt IPVersion );
 use Socket qw( AF_INET AF_INET6 );
 
-use Moose::Role;
+use Moo::Role;
 
 use integer;
 
@@ -66,7 +66,7 @@ sub _validate_ip_integer {
             unless ref $int;
     }
     else {
-        die "$int is not a valid IP integer for IPv4"
+        die "$int is not a valid integer for an IP address"
             if $int >= 2**32;
     }
 
