@@ -1,6 +1,6 @@
 package Net::Works::Util;
 {
-  $Net::Works::Util::VERSION = '0.11';
+  $Net::Works::Util::VERSION = '0.12';
 }
 BEGIN {
   $Net::Works::Util::AUTHORITY = 'cpan:DROLSKY';
@@ -87,7 +87,7 @@ Net::Works::Util - Utility subroutines for Net-Works
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 DESCRIPTION
 
@@ -112,6 +112,10 @@ Olaf Alders <oalders@wundercounter.com>
 
 =back
 
+=head1 CONTRIBUTOR
+
+William Stevenson <wstevenson@maxmind.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by MaxMind, Inc..
